﻿Public Class Temp
    Delegate Sub updateProgress(ByVal value)

    Public Sub Progress(ByVal value)
        ProgressBar1.Value = SerialPort1.ReadByte()
        Value_Label.Text = ProgressBar1.Value.ToString()

    End Sub
    Private Sub SerialPort1_DataReceived(ByVal sender As System.Object, ByVal e As System.IO.Ports.SerialDataReceivedEventArgs) Handles SerialPort1.DataReceived
        If Me.SerialPort1.BytesToRead <= 0 Then
            Return
        End If

        If ProgressBar1.InvokeRequired Then
            Dim d As New updateProgress(AddressOf Progress) ''Delegates are required since Receive is defaulted to a second thread
            ProgressBar1.Invoke(d, SerialPort1.ReadByte())
        Else
            ProgressBar1.Value = Me.SerialPort1.ReadByte
            Value_Label.Text = ProgressBar1.Value.ToString()
        End If

    End Sub

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ProgressBar1.Maximum = 200  ''initialize progress bar paramaters
        ProgressBar1.Minimum = 0
        ProgressBar1.Value = 0
        ProgressBar1.Step = 1

        initialize_serial() ''call routine to setup serial

    End Sub

    Private Sub initialize_serial()
        Try
            SerialComPortSelect.DataSource = System.IO.Ports.SerialPort.GetPortNames ''get list of available ports from Operating System
            If SerialComPortSelect.Items.Count > 0 Then  '' check for com ports installed on PC
                Dim index As Integer = -1
                index = (SerialComPortSelect.Items.Count - 1) ''Default to selecting/opening the highest port number.
                If SerialPort1.IsOpen Then
                    SerialPort1.Close()
                End If

                SerialComPortSelect.SelectedIndex = index  ''Set Combobox to our selected COM Port
                SerialComPortBaud.SelectedIndex = 5  ''Set the Baudrate Combobox to the selected Baud Rate
                SerialPort1.PortName = SerialComPortSelect.SelectedItem  ''Name our Port
                SerialPort1.BaudRate = 57600 ''Set Baud Rate
                SerialPort1.Parity = IO.Ports.Parity.None '' Set Parity
                SerialPort1.StopBits = IO.Ports.StopBits.One '' Set Stop Bits
                SerialPort1.DataBits = 8 ''Set Data Bits
                SerialPort1.Handshake = IO.Ports.Handshake.None ''Set Flow Control
                SerialPort1.Open() ''Open the Serial Port
                Button1.Text = "Disconnect" ''Update Connect/Disconnect Button

            Else
                MessageBox.Show("No COM ports available")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message)
        End Try
    End Sub

    Private Sub serialComPortBaud_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles serialComPortBaud.SelectedValueChanged
        Try

            Dim newBaudRate As Integer = Integer.Parse(SerialComPortBaud.SelectedItem) ''Get Selected Baud Rate

            If SerialPort1.IsOpen Then ''Check if Port is open
                SerialPort1.Close() ''Close port first
                SerialPort1.BaudRate = newBaudRate ''update baud rate
                SerialPort1.Open() ''Re-open port
            Else
                SerialPort1.BaudRate = newBaudRate ''change baudrate; port was closed so leave port closed
            End If
        Catch ex As InvalidOperationException
            MessageBox.Show("Error Opening Serial Port", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As UnauthorizedAccessException
            MessageBox.Show("Error Opening Serial Port: Port Already In Use", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As ArgumentOutOfRangeException
            MessageBox.Show("Serial Port Settings are Invalid", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As System.IO.IOException
            SerialPort1.Close()
            serialComPortBaud.Items.Remove(serialComPortBaud.SelectedItem)
            serialComPortBaud.SelectedIndex = 0
            SerialPort1.BaudRate = Integer.Parse(SerialComPortBaud.SelectedItem)
            SerialPort1.Open()
        End Try
    End Sub

    Private Sub Button1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Button1.Click
        If SerialPort1.IsOpen Then '' if port is open then button press closes port
            SerialPort1.Close()
            Button1.Text = "Connect"
        Else  ''port is closed; try and open the selected port
            Try
                If SerialPort1.PortName <> "" Then '' only try and open a port if one is selected
                    SerialPort1.Open()
                    Button1.Text = "Disconnect"
                End If
            Catch ex As Exception
                MessageBox.Show(ex.Message)
            End Try
        End If
    End Sub
End Class
